diff hgext/evolve.py @ 1369:4ed67cce8c23

evolve: properly evolve stacked unstable with --rev Before this patch, _singlesuccessor was not returning a revision number for the case where the parent of the argument was not obsolete. This resulted in bug when testing membership with the set of revisions. This patch fixes it and adds a test.
author Laurent Charignon <lcharignon@fb.com>
date Tue, 16 Jun 2015 14:30:43 -0700
parents f00d91365ab9
children 3d2d3333fb0b
line wrap: on
line diff
--- a/hgext/evolve.py	Tue Jun 16 10:19:17 2015 -0700
+++ b/hgext/evolve.py	Tue Jun 16 14:30:43 2015 -0700
@@ -1234,12 +1234,12 @@
         ui.status(_('working directory is now at %s\n') % repo['.'])
 
 def _singlesuccessor(repo, p):
     """returns p if not obsolete or its unique latest successors
 
     fail if there are no such successor"""
 
     if not p.obsolete():
-        return p
+        return p.rev()
     obs = repo[p]
     ui = repo.ui
     newer = obsolete.successorssets(repo, obs.node())
@@ -1234,12 +1234,12 @@
 
 def _singlesuccessor(repo, p):
-    """returns p if not obsolete or its unique latest successors
+    """returns p (as rev) if not obsolete or its unique latest successors
 
     fail if there are no such successor"""